summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorArthur Schiwon <blizzz@arthur-schiwon.de>2018-04-24 22:14:00 +0200
committerMorris Jobke <hey@morrisjobke.de>2018-04-26 12:00:06 +0200
commit5fbf184134f34633bc150b2e0210c4a97ec285a9 (patch)
treebdc4d79196f1268cf8d5df488c9b31705ceb82a0 /lib
parentb7e8ab97e731b77ef2ec519bfb98019516b7f682 (diff)
downloadnextcloud-server-5fbf184134f34633bc150b2e0210c4a97ec285a9.tar.gz
nextcloud-server-5fbf184134f34633bc150b2e0210c4a97ec285a9.zip
destaticfy Log classes
Signed-off-by: Arthur Schiwon <blizzz@arthur-schiwon.de>
Diffstat (limited to 'lib')
-rw-r--r--lib/composer/composer/autoload_classmap.php3
-rw-r--r--lib/composer/composer/autoload_static.php3
-rw-r--r--lib/private/Log.php46
-rw-r--r--lib/private/Log/Errorlog.php11
-rw-r--r--lib/private/Log/File.php52
-rw-r--r--lib/private/Log/IFileBased.php30
-rw-r--r--lib/private/Log/IWritable.php28
-rw-r--r--lib/private/Log/LogFactory.php66
-rw-r--r--lib/private/Log/Syslog.php17
-rw-r--r--lib/private/Server.php5
10 files changed, 176 insertions, 85 deletions
diff --git a/lib/composer/composer/autoload_classmap.php b/lib/composer/composer/autoload_classmap.php
index 19cb583cc93..f706fea2cbe 100644
--- a/lib/composer/composer/autoload_classmap.php
+++ b/lib/composer/composer/autoload_classmap.php
@@ -750,6 +750,9 @@ return array(
'OC\\Log\\Errorlog' => $baseDir . '/lib/private/Log/Errorlog.php',
'OC\\Log\\ExceptionSerializer' => $baseDir . '/lib/private/Log/ExceptionSerializer.php',
'OC\\Log\\File' => $baseDir . '/lib/private/Log/File.php',
+ 'OC\\Log\\IFileBased' => $baseDir . '/lib/private/Log/IFileBased.php',
+ 'OC\\Log\\IWritable' => $baseDir . '/lib/private/Log/IWritable.php',
+ 'OC\\Log\\LogFactory' => $baseDir . '/lib/private/Log/LogFactory.php',
'OC\\Log\\Rotate' => $baseDir . '/lib/private/Log/Rotate.php',
'OC\\Log\\Syslog' => $baseDir . '/lib/private/Log/Syslog.php',
'OC\\Mail\\Attachment' => $baseDir . '/lib/private/Mail/Attachment.php',
diff --git a/lib/composer/composer/autoload_static.php b/lib/composer/composer/autoload_static.php
index a913b0498b9..b879dc5a214 100644
--- a/lib/composer/composer/autoload_static.php
+++ b/lib/composer/composer/autoload_static.php
@@ -780,6 +780,9 @@ class ComposerStaticInit53792487c5a8370acc0b06b1a864ff4c
'OC\\Log\\Errorlog' => __DIR__ . '/../../..' . '/lib/private/Log/Errorlog.php',
'OC\\Log\\ExceptionSerializer' => __DIR__ . '/../../..' . '/lib/private/Log/ExceptionSerializer.php',
'OC\\Log\\File' => __DIR__ . '/../../..' . '/lib/private/Log/File.php',
+ 'OC\\Log\\IFileBased' => __DIR__ . '/../../..' . '/lib/private/Log/IFileBased.php',
+ 'OC\\Log\\IWritable' => __DIR__ . '/../../..' . '/lib/private/Log/IWritable.php',
+ 'OC\\Log\\LogFactory' => __DIR__ . '/../../..' . '/lib/private/Log/LogFactory.php',
'OC\\Log\\Rotate' => __DIR__ . '/../../..' . '/lib/private/Log/Rotate.php',
'OC\\Log\\Syslog' => __DIR__ . '/../../..' . '/lib/private/Log/Syslog.php',
'OC\\Mail\\Attachment' => __DIR__ . '/../../..' . '/lib/private/Mail/Attachment.php',
diff --git a/lib/private/Log/Errorlog.php b/lib/private/Log/Errorlog.php
index 37498c36aba..1302a31fe5c 100644
--- a/lib/private/Log/Errorlog.php
+++ b/lib/private/Log/Errorlog.php
@@ -25,14 +25,7 @@
namespace OC\Log;
-class Errorlog {
-
-
- /**
- * Init class data
- */
- public static function init() {
- }
+class Errorlog implements IWritable {
/**
* write a message in the log
@@ -40,7 +33,7 @@ class Errorlog {
* @param string $message
* @param int $level
*/
- public static function write($app, $message, $level) {
+ public function write($app, $message, $level) {
error_log('[owncloud]['.$app.']['.$level.'] '.$message);
}
}
diff --git a/lib/private/Log/File.php b/lib/private/Log/File.php
index 755c4729c7a..639e4de8ac7 100644
--- a/lib/private/Log/File.php
+++ b/lib/private/Log/File.php
@@ -45,28 +45,21 @@ use OCP\ILogger;
* Log is saved at data/nextcloud.log (on default)
*/
-class File {
- static protected $logFile;
+class File implements IWritable, IFileBased {
+ /** @var string */
+ protected $logFile;
- /**
- * Init class data
- */
- public static function init() {
- $systemConfig = \OC::$server->getSystemConfig();
- $defaultLogFile = $systemConfig->getValue("datadirectory", \OC::$SERVERROOT.'/data').'/nextcloud.log';
- self::$logFile = $systemConfig->getValue("logfile", $defaultLogFile);
-
- /**
- * Fall back to default log file if specified logfile does not exist
- * and can not be created.
- */
- if (!file_exists(self::$logFile)) {
- if(!is_writable(dirname(self::$logFile))) {
- self::$logFile = $defaultLogFile;
- } else {
- if(!touch(self::$logFile)) {
- self::$logFile = $defaultLogFile;
- }
+ public function __construct(string $path, string $fallbackPath = '') {
+ $this->logFile = $path;
+ if (!file_exists($this->logFile)) {
+ if(
+ (
+ !is_writable(dirname($this->logFile))
+ || !touch($this->logFile)
+ )
+ && $fallbackPath !== ''
+ ) {
+ $this->logFile = $fallbackPath;
}
}
}
@@ -77,7 +70,7 @@ class File {
* @param string|array $message
* @param int $level
*/
- public static function write($app, $message, $level) {
+ public function write($app, $message, $level) {
$config = \OC::$server->getSystemConfig();
// default to ISO8601
@@ -137,9 +130,9 @@ class File {
}
}
$entry = json_encode($entry, JSON_PARTIAL_OUTPUT_ON_ERROR);
- $handle = @fopen(self::$logFile, 'a');
- if ((fileperms(self::$logFile) & 0777) != 0640) {
- @chmod(self::$logFile, 0640);
+ $handle = @fopen($this->logFile, 'a');
+ if ((fileperms($this->logFile) & 0777) != 0640) {
+ @chmod($this->logFile, 0640);
}
if ($handle) {
fwrite($handle, $entry."\n");
@@ -159,11 +152,10 @@ class File {
* @param int $offset
* @return array
*/
- public static function getEntries($limit=50, $offset=0) {
- self::init();
+ public function getEntries($limit=50, $offset=0) {
$minLevel = \OC::$server->getSystemConfig()->getValue("loglevel", ILogger::WARN);
$entries = array();
- $handle = @fopen(self::$logFile, 'rb');
+ $handle = @fopen($this->logFile, 'rb');
if ($handle) {
fseek($handle, 0, SEEK_END);
$pos = ftell($handle);
@@ -205,7 +197,7 @@ class File {
/**
* @return string
*/
- public static function getLogFilePath() {
- return self::$logFile;
+ public function getLogFilePath() {
+ return $this->logFile;
}
}
diff --git a/lib/private/Log/IFileBased.php b/lib/private/Log/IFileBased.php
new file mode 100644
index 00000000000..ae083f670e2
--- /dev/null
+++ b/lib/private/Log/IFileBased.php
@@ -0,0 +1,30 @@
+<?php
+/**
+ * @copyright Copyright (c) 2018 Arthur Schiwon <blizzz@arthur-schiwon.de>
+ *
+ * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
+ *
+ * @license GNU AGPL version 3 or any later version
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
+
+namespace OC\Log;
+
+interface IFileBased {
+ public function getLogFilePath();
+
+ public function getEntries($limit=50, $offset=0);
+}
diff --git a/lib/private/Log/IWritable.php b/lib/private/Log/IWritable.php
new file mode 100644
index 00000000000..ff9bb4e71a8
--- /dev/null
+++ b/lib/private/Log/IWritable.php
@@ -0,0 +1,28 @@
+<?php
+/**
+ * @copyright Copyright (c) 2018 Arthur Schiwon <blizzz@arthur-schiwon.de>
+ *
+ * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
+ *
+ * @license GNU AGPL version 3 or any later version
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
+
+namespace OC\Log;
+
+interface IWritable {
+ public function write($app, $message, $level);
+}
diff --git a/lib/private/Log/LogFactory.php b/lib/private/Log/LogFactory.php
new file mode 100644
index 00000000000..13049083fee
--- /dev/null
+++ b/lib/private/Log/LogFactory.php
@@ -0,0 +1,66 @@
+<?php
+/**
+ * @copyright Copyright (c) 2018 Arthur Schiwon <blizzz@arthur-schiwon.de>
+ *
+ * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
+ *
+ * @license GNU AGPL version 3 or any later version
+ *
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU Affero General Public License for more details.
+ *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
+ *
+ */
+
+namespace OC\Log;
+
+use OCP\IServerContainer;
+
+class LogFactory {
+ /** @var IServerContainer */
+ private $c;
+
+ public function __construct(IServerContainer $c) {
+ $this->c = $c;
+ }
+
+ /**
+ * @param $type
+ * @return \OC\Log\Errorlog|File|\stdClass
+ * @throws \OCP\AppFramework\QueryException
+ */
+ public function get($type) {
+ switch (strtolower($type)) {
+ case 'errorlog':
+ return new Errorlog();
+ case 'syslog':
+ return $this->c->resolve(Syslog::class);
+ case 'file':
+ return $this->buildLogFile();
+
+ // Backwards compatibility for old and fallback for unknown log types
+ case 'owncloud':
+ case 'nextcloud':
+ default:
+ return $this->buildLogFile();
+ }
+ }
+
+ protected function buildLogFile() {
+ $config = $this->c->getConfig();
+ $defaultLogFile = $config->getSystemValue('datadirectory', \OC::$SERVERROOT.'/data').'/nextcloud.log';
+ $logFile = $config->getSystemValue('logfile', $defaultLogFile);
+ $fallback = $defaultLogFile !== $logFile ? $defaultLogFile : '';
+
+ return new File($logFile, $fallback);
+ }
+}
diff --git a/lib/private/Log/Syslog.php b/lib/private/Log/Syslog.php
index 7b3d931ef31..be8ecdebb2e 100644
--- a/lib/private/Log/Syslog.php
+++ b/lib/private/Log/Syslog.php
@@ -26,22 +26,19 @@
namespace OC\Log;
use OCP\ILogger;
+use OCP\IConfig;
-class Syslog {
- static protected $levels = array(
+class Syslog implements IWritable {
+ static protected $levels = [
ILogger::DEBUG => LOG_DEBUG,
ILogger::INFO => LOG_INFO,
ILogger::WARN => LOG_WARNING,
ILogger::ERROR => LOG_ERR,
ILogger::FATAL => LOG_CRIT,
- );
+ ];
- /**
- * Init class data
- */
- public static function init() {
- openlog(\OC::$server->getSystemConfig()->getValue("syslog_tag", "ownCloud"), LOG_PID | LOG_CONS, LOG_USER);
- // Close at shutdown
+ public function __construct(IConfig $config) {
+ openlog($config->getSystemValue('syslog_tag', 'ownCloud'), LOG_PID | LOG_CONS, LOG_USER);
register_shutdown_function('closelog');
}
@@ -51,7 +48,7 @@ class Syslog {
* @param string $message
* @param int $level
*/
- public static function write($app, $message, $level) {
+ public function write($app, $message, $level) {
$syslog_level = self::$levels[$level];
syslog($syslog_level, '{'.$app.'} '.$message);
}
diff --git a/lib/private/Server.php b/lib/private/Server.php
index 3786486c2b2..a4608bf7a8f 100644
--- a/lib/private/Server.php
+++ b/lib/private/Server.php
@@ -87,6 +87,7 @@ use OC\Lock\DBLockingProvider;
use OC\Lock\MemcacheLockingProvider;
use OC\Lock\NoopLockingProvider;
use OC\Lockdown\LockdownManager;
+use OC\Log\LogFactory;
use OC\Mail\Mailer;
use OC\Memcache\ArrayCache;
use OC\Memcache\Factory;
@@ -546,8 +547,8 @@ class Server extends ServerContainer implements IServerContainer {
$this->registerService(\OCP\ILogger::class, function (Server $c) {
$logType = $c->query('AllConfig')->getSystemValue('log_type', 'file');
- $logger = Log::getLogClass($logType);
- call_user_func(array($logger, 'init'));
+ $factory = new LogFactory($c);
+ $logger = $factory->get($logType);
$config = $this->getSystemConfig();
$registry = $c->query(\OCP\Support\CrashReport\IRegistry::class);
diff --git a/lib/private/Log.php b/lib/private/Log.php
index ffe8c665c6f..c6f676db588 100644
--- a/lib/private/Log.php
+++ b/lib/private/Log.php
@@ -38,7 +38,8 @@ namespace OC;
use InterfaSys\LogNormalizer\Normalizer;
use OC\Log\ExceptionSerializer;
-use OC\Log\File;
+use OC\Log\IFileBased;
+use OC\Log\IWritable;
use OCP\ILogger;
use OCP\Support\CrashReport\IRegistry;
use OCP\Util;
@@ -54,7 +55,7 @@ use OCP\Util;
*/
class Log implements ILogger {
- /** @var string */
+ /** @var IWritable */
private $logger;
/** @var SystemConfig */
@@ -70,27 +71,19 @@ class Log implements ILogger {
private $crashReporters;
/**
* @param string $logger The logger that should be used
* @param SystemConfig $config the system config object
* @param Normalizer|null $normalizer
* @param IRegistry|null $registry
*/
- public function __construct($logger = null, SystemConfig $config = null, $normalizer = null, IRegistry $registry = null) {
+ public function __construct(IWritable $logger, SystemConfig $config = null, $normalizer = null, IRegistry $registry = null) {
// FIXME: Add this for backwards compatibility, should be fixed at some point probably
if ($config === null) {
$config = \OC::$server->getSystemConfig();
}
$this->config = $config;
-
- // FIXME: Add this for backwards compatibility, should be fixed at some point probably
- if ($logger === null) {
- $logType = $this->config->getValue('log_type', 'file');
- $this->logger = static::getLogClass($logType);
- call_user_func([$this->logger, 'init']);
- } else {
- $this->logger = $logger;
- }
+ $this->logger = $logger;
if ($normalizer === null) {
$this->normalizer = new Normalizer();
} else {
@@ -302,7 +295,7 @@ class Log implements ILogger {
array_walk($context, [$this->normalizer, 'format']);
if ($level >= $minLevel) {
- if ($this->logger !== File::class) {
+ if (!$this->logger instanceof IFileBased) {
$data = json_encode($data, JSON_PARTIAL_OUTPUT_ON_ERROR);
}
$this->writeLog($app, $data, $level);
@@ -320,28 +313,13 @@ class Log implements ILogger {
* @param int $level
*/
protected function writeLog(string $app, $entry, int $level) {
- call_user_func([$this->logger, 'write'], $app, $entry, $level);
+ $this->logger->write($app, $entry, $level);
}
- /**
- * @param string $logType
- * @return string
- * @internal
- */
- public static function getLogClass(string $logType): string {
- switch (strtolower($logType)) {
- case 'errorlog':
- return \OC\Log\Errorlog::class;
- case 'syslog':
- return \OC\Log\Syslog::class;
- case 'file':
- return \OC\Log\File::class;
-
- // Backwards compatibility for old and fallback for unknown log types
- case 'owncloud':
- case 'nextcloud':
- default:
- return \OC\Log\File::class;
+ public function getLogPath():string {
+ if($this->logger instanceof IFileBased) {
+ return $this->logger->getLogFilePath();
}
+ throw new \RuntimeException('Log implementation has no path');
}
}
@@ -70,27 +71,19 @@ class Log implements ILogger {
private $crashReporters;
/**
- * @param string $logger The logger that should be used
+ * @param IWritable $logger The logger that should be used
* @param SystemConfig $config the system config object
* @param Normalizer|null $normalizer